@@ -13,11 +13,10 @@ class Api:
     def __init__(self):
         self.manager = Manager()
         self.get = self.manager.get_prod
+        self.list = self.manager.list_prod
+        self.clear = self.manager.clear_prod
         self.get_output = self.manager.get_output
         self.clear_output = self.manager.clear_output
-        self.get_history = self.manager.get_history
-        self.list_history = self.manager.list_history
-        self.clear_history = self.manager.clear_history
 
     def currents(self, raw=False):
         json_data = self.manager.get_naas()
@@ -45,16 +44,16 @@ class Api:
         if not self.manager.notebook_path():
             print("No add done you are in already in naas folder\n")
             return url
+        self.manager.add_prod(
+            {"type": self.role, "path": current_file, "params": params, "value": token},
+            debug,
+        )
         print("👌 Well done! Your Notebook has been sent to production folder.\n")
         print(f"🔑 You can run this notebook remotely with: {url} \n")
         self.manager.copy_url(url)
         print(
             'PS: to remove the "Notebook as API" feature, just replace .add by .delete'
         )
-        self.manager.add_prod(
-            {"type": self.role, "path": current_file, "params": params, "value": token},
-            not debug,
-        )
         return url
 
     def respond_notebook(self):
@@ -79,7 +78,8 @@ class Api:
         display(Markdown("Response Set as JSON, preview below: "))
         display(JSON(data, metadata={"naas_api": True}))
 
-    def respond_image(self, data, filename, mimetype):
+    def respond_image(self, data, filename):
+        mimetype = mimetypes.guess_type(filename)[0]
         display(Markdown("Response Set as IMAGE, preview below: "))
         display(
             Image(data, filename=filename, format=mimetype, metadata={"naas_api": True})
@@ -103,7 +103,7 @@ class Api:
             print("No delete done you are in already in naas folder\n")
             return
         current_file = self.manager.get_path(path)
-        self.manager.del_prod({"type": self.role, "path": current_file}, not debug)
+        self.manager.del_prod({"type": self.role, "path": current_file}, debug)
         print("🗑 Done! Your Notebook has been remove from production folder.\n")
         if all is True:
             self.clear_history(path)
