@@ -9,9 +9,8 @@ class Dependency:
     def __init__(self):
         self.manager = Manager()
         self.get = self.manager.get_prod
-        self.get_history = self.manager.get_history
-        self.list_history = self.manager.list_history
-        self.clear_history = self.manager.clear_history
+        self.list = self.manager.list_prod
+        self.clear = self.manager.clear_prod
 
     def currents(self, raw=False):
         json_data = self.manager.get_naas()
@@ -29,8 +28,6 @@ class Dependency:
             print("No add done you are in already in naas folder\n")
             return
         current_file = self.manager.get_path(path)
-        print("👌 Well done! Your Dependency has been sent to production folder. \n")
-        print('PS: to remove the "Dependency" feature, just replace .add by .delete')
         self.manager.add_prod(
             {
                 "type": self.role,
@@ -38,15 +35,17 @@ class Dependency:
                 "params": {},
                 "value": "Only internal",
             },
-            not debug,
+            debug,
         )
+        print("👌 Well done! Your Dependency has been sent to production folder. \n")
+        print('PS: to remove the "Dependency" feature, just replace .add by .delete')
 
     def delete(self, path=None, all=False, debug=False):
         if not self.manager.notebook_path():
             print("No delete done you are in already in naas folder\n")
             return
         current_file = self.manager.get_path(path)
-        self.manager.del_prod({"type": self.role, "path": current_file}, not debug)
+        self.manager.del_prod({"type": self.role, "path": current_file}, debug)
         print("🗑 Done! Your Dependency has been remove from production folder.\n")
         if all is True:
             self.clear_history(path)
